use [DataScience]
go


-- create the log for all symbols
drop table if exists dbo.log_for_buy_at_ema_10_gt_20


-- create dbo.log_for_buy_at_ema_10_gt_20
select 
 date
,symbol
,[open]
,[close]
,ema_10_lag_1
,ema_30_lag_1
,ema_10
,ema_20

-- set buy and sell signals
,case
	when ((ema_10_lag_1 <= ema_30_lag_1) and  (ema_10 > ema_20)) then 'buy signal'
	when ((ema_10_lag_1 >= ema_30_lag_1) and (ema_20 > ema_10)) then 'sell signal'
	else null
 end buy_sell_signal

-- set buy and sell prices
,case
	when ((ema_10_lag_1 <= ema_30_lag_1) and  (ema_10 > ema_20)) then open_lead_1
	when ((ema_10_lag_1 >= ema_30_lag_1) and (ema_20 > ema_10)) then open_lead_1
	else null
 end buy_sell_price

into dbo.log_for_buy_at_ema_10_gt_20

from
(
-- source rows for buy/sell actions
select 
 stooq_prices.* 
,denormalized_emas.ema_10
,denormalized_emas.ema_20
,denormalized_emas.ema_30
,denormalized_emas.ema_50
--,denormalized_emas.ema_200
,lag(denormalized_emas.ema_10,1) over (partition by stooq_prices.symbol 
		order by denormalized_emas.date) ema_10_lag_1
,lag(denormalized_emas.ema_30,1) over (partition by stooq_prices.symbol 
		order by denormalized_emas.date) ema_30_lag_1
,lead(stooq_prices.[open],1) over(partition by stooq_prices.symbol 
		order by  denormalized_emas.date) open_lead_1

from DataScience.dbo.stooq_prices
inner join DataScience.dbo.denormalized_emas
on stooq_prices.date = denormalized_emas.date
and stooq_prices.symbol = denormalized_emas.symbol
) for_buy_sell_log_for_ema_10_vs_20

select * from dbo.log_for_buy_at_ema_10_gt_20
go

--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------
--/*

-- Prepare for cleaning the log for AAPL

-- declarations
declare 
	@symbol nvarchar(10) = 'AAPL'
   ,@first_buy_signal_date date
   ,@first_sell_signal_date date
   ,@prior_buy_signal_date date
   ,@prior_sell_signal_date date
   ,@next_buy_signal_date date
   ,@next_sell_signal_date date

-- create and populate a temp log for a symbol 
-- with buy_sell_signal dates (next_date)
drop table if exists dbo.symbol_temp_log

select [date]
      ,[symbol]
      ,[open]
      ,[close]
      ,[ema_10_lag_1]
      ,[ema_30_lag_1]
      ,[ema_10]
      ,[ema_20]
      ,[buy_sell_signal]
      ,[buy_sell_price]
	  ,lead(date,1) over (partition by symbol order by date) next_date
into dbo.symbol_temp_log
from   [DataScience].[dbo].[log_for_buy_at_ema_10_gt_20]
where symbol = @symbol

-- optionally echo two resource tables
-- log for all symbols
-- select * from dbo.log_for_buy_at_ema_10_gt_20
-- log for current symbol
-- select * from dbo.symbol_temp_log

--------------------------------------------------------------------------------------

-- create a fresh version of a table for buy_sell 
-- cycle dates with a symbol
-- dbo.symbol_buy_sell_cycle_date has just one pair of dates 
-- for each buy_sell cycle


drop table if exists dbo.symbol_buy_sell_cycle_date

create table dbo.symbol_buy_sell_cycle_date(
	 [symbol] [nvarchar](10) not NULL
	,[buy_sell_cycle_date] [date] NOT NULL,
)


-- compute @first_buy_signal_date and @first_sell_signal_date
-- and insert into dbo.symbol_buy_sell_cycle_date

set @first_buy_signal_date = (select min(next_date) 
from symbol_temp_log
where buy_sell_signal = 'buy signal')

set @first_sell_signal_date = (select min(next_date)
from symbol_temp_log
where buy_sell_signal = 'sell signal')

insert dbo.symbol_buy_sell_cycle_date
select *
from
(
select @symbol [symbol], @first_buy_signal_date [buy_sell_cycle_date]
union
select @symbol [symbol], @first_sell_signal_date [buy_sell_cycle_date]
) buy_sell_cycle_dates

set @prior_buy_signal_date = @first_buy_signal_date
set @prior_sell_signal_date = @first_sell_signal_date


-- after search for @first_buy_signal_date and @first_sell_signal_date
-- search iteratively for @next_buy_signal_date and @next_sell_signal_date

Next_Buy_Sell_Date_Pair:
set @next_buy_signal_date = (select min(next_date) next_buy_signal_date
from symbol_temp_log 
where buy_sell_signal = 'buy signal' and next_date > @prior_sell_signal_date)

set @next_sell_signal_date = (select min(next_date) next_sell_signal_date 
from symbol_temp_log
where buy_sell_signal = 'sell signal' and next_date > @next_buy_signal_date)

-- assign @next_buy_signal_date and @next_sell_signal_date
-- to @prior_buy_signal_date and @prior_buy_signal_date
-- for next iterative search if another search is needed
set @prior_buy_signal_date = @next_buy_signal_date
set @prior_sell_signal_date = @next_sell_signal_date


-- cease searching iteratively when at least one null date value is returned 
-- when no null returned, then insert cycle dates into symbol_buy_sell_cycle_date table
if @next_buy_signal_date is not null and @next_sell_signal_date is not null
begin

	insert dbo.symbol_buy_sell_cycle_date
	select *
	from
	(
	select @symbol [symbol], @next_buy_signal_date [buy_sell_cycle_date]
	union
	select @symbol [symbol], @next_sell_signal_date [buy_sell_cycle_date]
	) buy_sell_cycle_dates

	goto Next_Buy_Sell_Date_Pair

end
else 
begin
	
	-- optionally display symbol_buy_sell_cycle_date table
	-- after all buy_sell cycle dataes are discovered 
	-- for the current symbol
	   select * from dbo.symbol_buy_sell_cycle_date

	   return

end


--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------

--/*
go
-- Prepare for cleaning the log for GOOGL

-- declarations
declare 
	@symbol nvarchar(10) = 'GOOGL'
   ,@first_buy_signal_date date
   ,@first_sell_signal_date date
   ,@prior_buy_signal_date date
   ,@prior_sell_signal_date date
   ,@next_buy_signal_date date
   ,@next_sell_signal_date date

-- create and populate a temp log for a symbol 
-- with buy_sell_signal dates (next_date)
drop table if exists dbo.symbol_temp_log

select [date]
      ,[symbol]
      ,[open]
      ,[close]
      ,[ema_10_lag_1]
      ,[ema_30_lag_1]
      ,[ema_10]
      ,[ema_20]
      ,[buy_sell_signal]
      ,[buy_sell_price]
	  ,lead(date,1) over (partition by symbol order by date) next_date
into dbo.symbol_temp_log
from   [DataScience].[dbo].[log_for_buy_at_ema_10_gt_20]
where symbol = @symbol

-- optionally echo two resource tables
-- log for all symbols
-- select * from dbo.log_for_buy_at_ema_10_gt_20
-- log for current symbols
-- select * from dbo.symbol_temp_log

--------------------------------------------------------------------------------------

-- create a fresh version of a table for buy_sell 
-- cycle dates with a symbol
-- dbo.symbol_buy_sell_cycle_date has just one pair of dates 
-- for each buy_sell cycle


drop table if exists dbo.symbol_buy_sell_cycle_date

create table dbo.symbol_buy_sell_cycle_date(
	 [symbol] [nvarchar](10) not NULL
	,[buy_sell_cycle_date] [date] NOT NULL,
)


-- compute @first_buy_signal_date and @first_sell_signal_date
-- and insert into dbo.symbol_buy_sell_cycle_date

set @first_buy_signal_date = (select min(next_date) 
from symbol_temp_log
where buy_sell_signal = 'buy signal')

set @first_sell_signal_date = (select min(next_date)
from symbol_temp_log
where buy_sell_signal = 'sell signal')

set @prior_buy_signal_date = @first_buy_signal_date
set @prior_sell_signal_date = @first_sell_signal_date

insert dbo.symbol_buy_sell_cycle_date
select *
from
(
select @symbol [symbol], @first_buy_signal_date [buy_sell_cycle_date]
union
select @symbol [symbol], @first_sell_signal_date [buy_sell_cycle_date]
) buy_sell_cycle_dates


-- after search for @first_buy_signal_date and @first_sell_signal_date
-- search iteratively for @next_buy_signal_date and @next_sell_signal_date

Next_Buy_Sell_Date_Pair:
set @next_buy_signal_date = (select min(next_date) next_buy_signal_date
from symbol_temp_log 
where buy_sell_signal = 'buy signal' and next_date > @prior_sell_signal_date)

set @next_sell_signal_date = (select min(next_date) next_sell_signal_date 
from symbol_temp_log
where buy_sell_signal = 'sell signal' and next_date > @next_buy_signal_date)

-- assign @next_buy_signal_date and @next_sell_signal_date
-- to @prior_buy_signal_date and @prior_buy_signal_date
-- for next iterative search if another search is needed
set @prior_buy_signal_date = @next_buy_signal_date
set @prior_sell_signal_date = @next_sell_signal_date


-- cease searching iteratively when at least one null date value is returned 
-- when no null returned, then insert cycle dates into symbol_buy_sell_cycle_date table
if @next_buy_signal_date is not null and @next_sell_signal_date is not null
begin

	insert dbo.symbol_buy_sell_cycle_date
	select *
	from
	(
	select @symbol [symbol], @next_buy_signal_date [buy_sell_cycle_date]
	union
	select @symbol [symbol], @next_sell_signal_date [buy_sell_cycle_date]
	) buy_sell_cycle_dates

	goto Next_Buy_Sell_Date_Pair

end
else 
begin
	
	-- optionally display symbol_buy_sell_cycle_date table
	-- after all buy_sell cycle dataes are discovered 
	-- for the current symbol
	   select * from dbo.symbol_buy_sell_cycle_date

	return

end



go
-- Prepare for cleaning the log for MSFT

-- declarations
declare 
	@symbol nvarchar(10) = 'MSFT'
   ,@first_buy_signal_date date
   ,@first_sell_signal_date date
   ,@prior_buy_signal_date date
   ,@prior_sell_signal_date date
   ,@next_buy_signal_date date
   ,@next_sell_signal_date date

-- create and populate a temp log for a symbol 
-- with buy_sell_signal dates (next_date)
drop table if exists dbo.symbol_temp_log

select [date]
      ,[symbol]
      ,[open]
      ,[close]
      ,[ema_10_lag_1]
      ,[ema_30_lag_1]
      ,[ema_10]
      ,[ema_20]
      ,[buy_sell_signal]
      ,[buy_sell_price]
	  ,lead(date,1) over (partition by symbol order by date) next_date
into dbo.symbol_temp_log
from   [DataScience].[dbo].[log_for_buy_at_ema_10_gt_20]
where symbol = @symbol

-- optionally echo two resource tables
-- log for all symbols
-- select * from dbo.log_for_buy_at_ema_10_gt_20
-- log for current symbols
-- select * from dbo.symbol_temp_log

--------------------------------------------------------------------------------------

-- create a fresh version of a table for buy_sell 
-- cycle dates with a symbol
-- dbo.symbol_buy_sell_cycle_date has just one pair of dates 
-- for each buy_sell cycle


drop table if exists dbo.symbol_buy_sell_cycle_date

create table dbo.symbol_buy_sell_cycle_date(
	 [symbol] [nvarchar](10) not NULL
	,[buy_sell_cycle_date] [date] NOT NULL,
)


-- compute @first_buy_signal_date and @first_sell_signal_date
-- and insert into dbo.symbol_buy_sell_cycle_date

set @first_buy_signal_date = (select min(next_date) 
from symbol_temp_log
where buy_sell_signal = 'buy signal')

set @first_sell_signal_date = (select min(next_date)
from symbol_temp_log
where buy_sell_signal = 'sell signal')

set @prior_buy_signal_date = @first_buy_signal_date
set @prior_sell_signal_date = @first_sell_signal_date

insert dbo.symbol_buy_sell_cycle_date
select *
from
(
select @symbol [symbol], @first_buy_signal_date [buy_sell_cycle_date]
union
select @symbol [symbol], @first_sell_signal_date [buy_sell_cycle_date]
) buy_sell_cycle_dates


-- after search for @first_buy_signal_date and @first_sell_signal_date
-- search iteratively for @next_buy_signal_date and @next_sell_signal_date

Next_Buy_Sell_Date_Pair:
set @next_buy_signal_date = (select min(next_date) next_buy_signal_date
from symbol_temp_log 
where buy_sell_signal = 'buy signal' and next_date > @prior_sell_signal_date)

set @next_sell_signal_date = (select min(next_date) next_sell_signal_date 
from symbol_temp_log
where buy_sell_signal = 'sell signal' and next_date > @next_buy_signal_date)

-- assign @next_buy_signal_date and @next_sell_signal_date
-- to @prior_buy_signal_date and @prior_buy_signal_date
-- for next iterative search if another search is needed
set @prior_buy_signal_date = @next_buy_signal_date
set @prior_sell_signal_date = @next_sell_signal_date


-- cease searching iteratively when at least one null date value is returned 
-- when no null returned, then insert cycle dates into symbol_buy_sell_cycle_date table
if @next_buy_signal_date is not null and @next_sell_signal_date is not null
begin

	insert dbo.symbol_buy_sell_cycle_date
	select *
	from
	(
	select @symbol [symbol], @next_buy_signal_date [buy_sell_cycle_date]
	union
	select @symbol [symbol], @next_sell_signal_date [buy_sell_cycle_date]
	) buy_sell_cycle_dates

	goto Next_Buy_Sell_Date_Pair

end
else 
begin
	
	-- optionally display symbol_buy_sell_cycle_date table
	-- after all buy_sell cycle dataes are discovered 
	-- for the current symbol
	   select * from dbo.symbol_buy_sell_cycle_date

	return

end



--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------

--/*

go
-- Prepare for cleaning the log for SPXL

-- declarations
declare 
	@symbol nvarchar(10) = 'SPXL'
   ,@first_buy_signal_date date
   ,@first_sell_signal_date date
   ,@prior_buy_signal_date date
   ,@prior_sell_signal_date date
   ,@next_buy_signal_date date
   ,@next_sell_signal_date date

-- create and populate a temp log for a symbol 
-- with buy_sell_signal dates (next_date)
drop table if exists dbo.symbol_temp_log

select [date]
      ,[symbol]
      ,[open]
      ,[close]
      ,[ema_10_lag_1]
      ,[ema_30_lag_1]
      ,[ema_10]
      ,[ema_20]
      ,[buy_sell_signal]
      ,[buy_sell_price]
	  ,lead(date,1) over (partition by symbol order by date) next_date
into dbo.symbol_temp_log
from   [DataScience].[dbo].[log_for_buy_at_ema_10_gt_20]
where symbol = @symbol

-- optionally echo two resource tables
-- log for all symbols
-- select * from dbo.log_for_buy_at_ema_10_gt_20
-- log for current symbols
-- select * from dbo.symbol_temp_log

--------------------------------------------------------------------------------------

-- create a fresh version of a table for buy_sell 
-- cycle dates with a symbol
-- dbo.symbol_buy_sell_cycle_date has just one pair of dates 
-- for each buy_sell cycle


drop table if exists dbo.symbol_buy_sell_cycle_date

create table dbo.symbol_buy_sell_cycle_date(
	 [symbol] [nvarchar](10) not NULL
	,[buy_sell_cycle_date] [date] NOT NULL,
)


-- compute @first_buy_signal_date and @first_sell_signal_date
-- and insert into dbo.symbol_buy_sell_cycle_date

set @first_buy_signal_date = (select min(next_date) 
from symbol_temp_log
where buy_sell_signal = 'buy signal')

set @first_sell_signal_date = (select min(next_date)
from symbol_temp_log
where buy_sell_signal = 'sell signal')

set @prior_buy_signal_date = @first_buy_signal_date
set @prior_sell_signal_date = @first_sell_signal_date

insert dbo.symbol_buy_sell_cycle_date
select *
from
(
select @symbol [symbol], @first_buy_signal_date [buy_sell_cycle_date]
union
select @symbol [symbol], @first_sell_signal_date [buy_sell_cycle_date]
) buy_sell_cycle_dates


-- after search for @first_buy_signal_date and @first_sell_signal_date
-- search iteratively for @next_buy_signal_date and @next_sell_signal_date

Next_Buy_Sell_Date_Pair:
set @next_buy_signal_date = (select min(next_date) next_buy_signal_date
from symbol_temp_log 
where buy_sell_signal = 'buy signal' and next_date > @prior_sell_signal_date)

set @next_sell_signal_date = (select min(next_date) next_sell_signal_date 
from symbol_temp_log
where buy_sell_signal = 'sell signal' and next_date > @next_buy_signal_date)

-- assign @next_buy_signal_date and @next_sell_signal_date
-- to @prior_buy_signal_date and @prior_buy_signal_date
-- for next iterative search if another search is needed
set @prior_buy_signal_date = @next_buy_signal_date
set @prior_sell_signal_date = @next_sell_signal_date


-- cease searching iteratively when at least one null date value is returned 
-- when no null returned, then insert cycle dates into symbol_buy_sell_cycle_date table
if @next_buy_signal_date is not null and @next_sell_signal_date is not null
begin

	insert dbo.symbol_buy_sell_cycle_date
	select *
	from
	(
	select @symbol [symbol], @next_buy_signal_date [buy_sell_cycle_date]
	union
	select @symbol [symbol], @next_sell_signal_date [buy_sell_cycle_date]
	) buy_sell_cycle_dates

	goto Next_Buy_Sell_Date_Pair

end
else 
begin
	
	-- optionally display symbol_buy_sell_cycle_date table
	-- after all buy_sell cycle dataes are discovered 
	-- for the current symbol
	   select * from dbo.symbol_buy_sell_cycle_date

	return

end

--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------

--/*

go
-- Prepare for cleaning the log for TQQQ

-- declarations
declare 
	@symbol nvarchar(10) = 'TQQQ'
   ,@first_buy_signal_date date
   ,@first_sell_signal_date date
   ,@prior_buy_signal_date date
   ,@prior_sell_signal_date date
   ,@next_buy_signal_date date
   ,@next_sell_signal_date date

-- create and populate a temp log for a symbol 
-- with buy_sell_signal dates (next_date)
drop table if exists dbo.symbol_temp_log

select [date]
      ,[symbol]
      ,[open]
      ,[close]
      ,[ema_10_lag_1]
      ,[ema_30_lag_1]
      ,[ema_10]
      ,[ema_20]
      ,[buy_sell_signal]
      ,[buy_sell_price]
	  ,lead(date,1) over (partition by symbol order by date) next_date
into dbo.symbol_temp_log
from   [DataScience].[dbo].[log_for_buy_at_ema_10_gt_20]
where symbol = @symbol

-- optionally echo two resource tables
-- log for all symbols
-- select * from dbo.log_for_buy_at_ema_10_gt_20
-- log for current symbols
-- select * from dbo.symbol_temp_log

--------------------------------------------------------------------------------------

-- create a fresh version of a table for buy_sell 
-- cycle dates with a symbol
-- dbo.symbol_buy_sell_cycle_date has just one pair of dates 
-- for each buy_sell cycle


drop table if exists dbo.symbol_buy_sell_cycle_date

create table dbo.symbol_buy_sell_cycle_date(
	 [symbol] [nvarchar](10) not NULL
	,[buy_sell_cycle_date] [date] NOT NULL,
)


-- compute @first_buy_signal_date and @first_sell_signal_date
-- and insert into dbo.symbol_buy_sell_cycle_date

set @first_buy_signal_date = (select min(next_date) 
from symbol_temp_log
where buy_sell_signal = 'buy signal')

set @first_sell_signal_date = (select min(next_date)
from symbol_temp_log
where buy_sell_signal = 'sell signal')

set @prior_buy_signal_date = @first_buy_signal_date
set @prior_sell_signal_date = @first_sell_signal_date

insert dbo.symbol_buy_sell_cycle_date
select *
from
(
select @symbol [symbol], @first_buy_signal_date [buy_sell_cycle_date]
union
select @symbol [symbol], @first_sell_signal_date [buy_sell_cycle_date]
) buy_sell_cycle_dates


-- after search for @first_buy_signal_date and @first_sell_signal_date
-- search iteratively for @next_buy_signal_date and @next_sell_signal_date

Next_Buy_Sell_Date_Pair:
set @next_buy_signal_date = (select min(next_date) next_buy_signal_date
from symbol_temp_log 
where buy_sell_signal = 'buy signal' and next_date > @prior_sell_signal_date)

set @next_sell_signal_date = (select min(next_date) next_sell_signal_date 
from symbol_temp_log
where buy_sell_signal = 'sell signal' and next_date > @next_buy_signal_date)

-- assign @next_buy_signal_date and @next_sell_signal_date
-- to @prior_buy_signal_date and @prior_buy_signal_date
-- for next iterative search if another search is needed
set @prior_buy_signal_date = @next_buy_signal_date
set @prior_sell_signal_date = @next_sell_signal_date


-- cease searching iteratively when at least one null date value is returned 
-- when no null returned, then insert cycle dates into symbol_buy_sell_cycle_date table
if @next_buy_signal_date is not null and @next_sell_signal_date is not null
begin

	insert dbo.symbol_buy_sell_cycle_date
	select *
	from
	(
	select @symbol [symbol], @next_buy_signal_date [buy_sell_cycle_date]
	union
	select @symbol [symbol], @next_sell_signal_date [buy_sell_cycle_date]
	) buy_sell_cycle_dates

	goto Next_Buy_Sell_Date_Pair

end
else 
begin
	
	-- optionally display symbol_buy_sell_cycle_date table
	-- after all buy_sell cycle dataes are discovered 
	-- for the current symbol
	   select * from dbo.symbol_buy_sell_cycle_date

	return

end

--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------

--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------

--/*

go
-- Prepare for cleaning the log for UDOW

-- declarations
declare 
	@symbol nvarchar(10) = 'UDOW'
   ,@first_buy_signal_date date
   ,@first_sell_signal_date date
   ,@prior_buy_signal_date date
   ,@prior_sell_signal_date date
   ,@next_buy_signal_date date
   ,@next_sell_signal_date date

-- create and populate a temp log for a symbol 
-- with buy_sell_signal dates (next_date)
drop table if exists dbo.symbol_temp_log

select [date]
      ,[symbol]
      ,[open]
      ,[close]
      ,[ema_10_lag_1]
      ,[ema_30_lag_1]
      ,[ema_10]
      ,[ema_20]
      ,[buy_sell_signal]
      ,[buy_sell_price]
	  ,lead(date,1) over (partition by symbol order by date) next_date
into dbo.symbol_temp_log
from   [DataScience].[dbo].[log_for_buy_at_ema_10_gt_20]
where symbol = @symbol

-- optionally echo two resource tables
-- log for all symbols
-- select * from dbo.log_for_buy_at_ema_10_gt_20
-- log for current symbols
-- select * from dbo.symbol_temp_log

--------------------------------------------------------------------------------------

-- create a fresh version of a table for buy_sell 
-- cycle dates with a symbol
-- dbo.symbol_buy_sell_cycle_date has just one pair of dates 
-- for each buy_sell cycle


drop table if exists dbo.symbol_buy_sell_cycle_date

create table dbo.symbol_buy_sell_cycle_date(
	 [symbol] [nvarchar](10) not NULL
	,[buy_sell_cycle_date] [date] NOT NULL,
)


-- compute @first_buy_signal_date and @first_sell_signal_date
-- and insert into dbo.symbol_buy_sell_cycle_date

set @first_buy_signal_date = (select min(next_date) 
from symbol_temp_log
where buy_sell_signal = 'buy signal')

set @first_sell_signal_date = (select min(next_date)
from symbol_temp_log
where buy_sell_signal = 'sell signal')

set @prior_buy_signal_date = @first_buy_signal_date
set @prior_sell_signal_date = @first_sell_signal_date

insert dbo.symbol_buy_sell_cycle_date
select *
from
(
select @symbol [symbol], @first_buy_signal_date [buy_sell_cycle_date]
union
select @symbol [symbol], @first_sell_signal_date [buy_sell_cycle_date]
) buy_sell_cycle_dates


-- after search for @first_buy_signal_date and @first_sell_signal_date
-- search iteratively for @next_buy_signal_date and @next_sell_signal_date

Next_Buy_Sell_Date_Pair:
set @next_buy_signal_date = (select min(next_date) next_buy_signal_date
from symbol_temp_log 
where buy_sell_signal = 'buy signal' and next_date > @prior_sell_signal_date)

set @next_sell_signal_date = (select min(next_date) next_sell_signal_date 
from symbol_temp_log
where buy_sell_signal = 'sell signal' and next_date > @next_buy_signal_date)

-- assign @next_buy_signal_date and @next_sell_signal_date
-- to @prior_buy_signal_date and @prior_buy_signal_date
-- for next iterative search if another search is needed
set @prior_buy_signal_date = @next_buy_signal_date
set @prior_sell_signal_date = @next_sell_signal_date


-- cease searching iteratively when at least one null date value is returned 
-- when no null returned, then insert cycle dates into symbol_buy_sell_cycle_date table
if @next_buy_signal_date is not null and @next_sell_signal_date is not null
begin

	insert dbo.symbol_buy_sell_cycle_date
	select *
	from
	(
	select @symbol [symbol], @next_buy_signal_date [buy_sell_cycle_date]
	union
	select @symbol [symbol], @next_sell_signal_date [buy_sell_cycle_date]
	) buy_sell_cycle_dates

	goto Next_Buy_Sell_Date_Pair

end
else 
begin
	
	-- optionally display symbol_buy_sell_cycle_date table
	-- after all buy_sell cycle dataes are discovered 
	-- for the current symbol
	   select * from dbo.symbol_buy_sell_cycle_date

	return

end

--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------


