use DataScience
go


/*
-- optionally, display underlying source data for
-- computing exponential moving averages
select [date]
      ,[symbol]
      ,[open]
      ,[high]
      ,[low]
      ,[close]
      ,[volume]
from   [DataScience].[dbo].[stooq_prices]
where symbol = 'AAPL'
*/


/*
-- optionally, display rows from datedimension table
select [date]
      ,[dayname]
      ,[daynumber]
      ,[monthname]
      ,[monthnumber]
      ,[year]
from   [DataScience].[dbo].[datedimension]
*/


--/*
-- optionally, display distinct symbols in stooq_prices
-- select distinct symbol from [DataScience].[dbo].[stooq_prices]

-- create a fresh version of the emas_for_stooq_prices table
drop table if exists dbo.table_of_symbols
go

-- populate table of symbols
select row_number() over (order by symbol) symbol_number, symbol
into dbo.table_of_symbols
from
(
-- display distinct symbols in [DataScience].[dbo].[stooq_prices]
select distinct symbol from [DataScience].[dbo].[stooq_prices]
) for_symbol_table

-- optionally, display table_of_symbols
-- select * from dbo.table_of_symbols
--*/

--/*

-- create a fresh version of the emas_for_stooq_prices table
drop table if exists dbo.emas_for_stooq_prices

-- create dbo.emas_for_stooq_prices table
create table dbo.emas_for_stooq_prices(
    [row_number] int NOT NULL,
	[date] [date] NOT NULL,
	[symbol] [nvarchar](10) NOT NULL,
	[ema_10] [money] NULL,
	[ema_20] [money] NULL,
) 
go

-- create foreign key reference to datedimension table
alter table dbo.emas_for_stooq_prices with nocheck add constraint [fkey_date] foreign key([date])
references dbo.datedimension ([date])
on update cascade
on delete cascade
go

-- enable foreign key constraint
alter table dbo.emas_for_stooq_prices check constraint fkey_date
go

----------------------------------------------------------------------------------------------

-- declare local variables 
declare
 @symbol nvarchar(10)
,@max_symbol_number int = (select max(symbol_number) from dbo.table_of_symbols)
,@symbol_index int = 1
,@alpha_10 float = 2.0/(10+1)
,@alpha_20 float = 2.0/(20+1)
,@current_row_number int = 3
,@max_row_number int = (select max(row_number) from datedimension_with_row_numbers)
,@xt money
,@ema_10_lag_1 money
,@ema_10 money
,@ema_20_lag_1 money
,@ema_20 money


-- while loop for iterating through symbols
while @symbol_index <= @max_symbol_number
begin

	-- assign a fresh value to @symbol from table_of_symbols
	select @symbol = symbol from table_of_symbols where symbol_number = @symbol_index

	-- populate first two rows in emas_for_stooq_prices
	insert into dbo.emas_for_stooq_prices
	(
	 symbol
	,date
	,row_number
	,ema_10
	,ema_20
	)
	--*/
	-- values for first two rows in dbo.emas_for_stooq_prices
	select 
	 symbol
	,date
	,case
		when rn = 1 then 1
		when rn = 2 then 2
	 end row_number
	,case
		when rn = 2 then lag([close],1) over (order by date)
	 end ema_10
	,case
		when rn = 2 then lag([close],1) over (order by date)
	 end ema_20
	from
	(
	-- rn, symbol, date, close 
	select 
	 row_number() over (order by stooq_prices.date) rn
	,@symbol symbol
	,stooq_prices.date
	,[close]
	from dbo.datedimension
	inner join dbo.stooq_prices
	on stooq_prices.date = datedimension.date
	where stooq_prices.symbol = @symbol
	) for_priming_
	where rn <= 2

	-- optionally, display top two rows from emas_for_stooq_prices
	-- select * from dbo.emas_for_stooq_prices

	-- compute exponential moving averages for
	-- all remaining underlying source data rows
	while @current_row_number <= @max_row_number
	begin

		-- retrieve close value (@xt) for @current_row_number
		set @xt = (select [close]
		from dbo.datedimension_with_row_numbers
		join dbo.stooq_prices on datedimension_with_row_numbers.date = stooq_prices.date
		where datedimension_with_row_numbers.row_number = @current_row_number and stooq_prices.symbol = @symbol)

		-- retrieve ema_10 for prior row
		set @ema_10_lag_1 =(select ema_10
		from dbo.datedimension_with_row_numbers
		--join dbo.stooq_prices on datedimension_with_row_numbers.date = stooq_prices.date
		join dbo.emas_for_stooq_prices on datedimension_with_row_numbers.date = emas_for_stooq_prices.date
		where datedimension_with_row_numbers.row_number = (@current_row_number-1) and emas_for_stooq_prices.symbol = @symbol)

		-- compute ema_10 for @current_row_number
		set @ema_10 = (@alpha_10*@xt) + ((1-@alpha_10)*@ema_10_lag_1)

		-- retrieve ema_20 for prior row
		set @ema_20_lag_1 =(select ema_20
		from dbo.datedimension_with_row_numbers
		--join dbo.stooq_prices on datedimension_with_row_numbers.date = stooq_prices.date
		join dbo.emas_for_stooq_prices on datedimension_with_row_numbers.date = emas_for_stooq_prices.date
		where datedimension_with_row_numbers.row_number = (@current_row_number-1) and emas_for_stooq_prices.symbol = @symbol)

		-- compute ema_20 for @current_row_number
		set @ema_20 = (@alpha_20*@xt) + ((1-@alpha_20)*@ema_20_lag_1)

		-- insert row into emas_for_stooq_prices for @current_row_number
		insert into dbo.emas_for_stooq_prices
		(
		 row_number
		,symbol
		,date
		,ema_10
		,ema_20
		)
		select 
		 @current_row_number
		,@symbol symbol
		,(
			select [date]
			from dbo.datedimension_with_row_numbers
			where datedimension_with_row_numbers.row_number = @current_row_number
			) date
		,@ema_10
		,@ema_20

		-- set @current_row_number for next while condition criterion
		set @current_row_number = @current_row_number + 1

	end

	set @symbol_index = @symbol_index + 1
	set @current_row_number = 3
end

-- display first ten rows from emas_for_stooq_prices
   select * from dbo.emas_for_stooq_prices where row_number <=10 order by symbol, row_number

-- display last ten rows from emas_for_stooq_prices
   select * from dbo.emas_for_stooq_prices where row_number >= (@max_row_number-9)  order by symbol, row_number

-- optionally, display all from emas_for_stooq_prices
   --select * from dbo.emas_for_stooq_prices order by symbol, row_number
